# Working with World Bank Climate Data 
# 

# get the R packages used in this demonstration
install.packages("rWBclimate") # get the world bank climate data api package 

# load the packages 
library("rWBclimate") 

# in this example we'll download historical temperature data  
gbr.historical <- get_historical_temp("GBR", "year")

# analyze trends versus the base temperature chart
cor(gbr.historical$data, gbr.historical$year) # corelation coefficient

# plot the chart using base R graphics
plot(gbr.historical$year, gbr.historical$data,type = 'l',xlab = 'Year', ylab = 'Temperature',main = 'UK temperatures 1900-2010')

# compute three regression models 
lmTemp <- lm(gbr.historical$data ~ gbr.historical$year) # linear model 
qdTemp <- update(lmTemp, . ~ . + I(gbr.historical$year^2)) # quadratic model 
cuTemp = update(qdTemp, . ~ . + I(gbr.historical$year^3)) # cubic model

# a function to evluate a polynomial given its coeficients to plot the regression models
polynomial = Vectorize(function(x, ps) {
  n = length(ps)
  sum(ps * x^(1:n-1))
}, "x") 

# plot the temperature data and the regression models 
plot(gbr.historical$year, gbr.historical$data,type = 'l',xlab = 'Year', ylab = 'Temperature',main = 'UK temperatures 1900-2010')
curve(polynomial(x, coef(lmTemp)), add = TRUE, col = 'red') # add the linear model 
curve(polynomial(x, coef(qdTemp)), add = TRUE, col = 'black', lty=2)  # add the quadratic model 
curve(polynomial(x, coef(cuTemp)), add = TRUE, col = 'blue')  # add the cubic model
legend(1900, 9.7, legend = c("linear", "quadratic", "cubic"), lty = c(1,2,1), col = c('red','black','blue')) 

# repeat the trend analysis for the US
usa.historical <- get_historical_temp("USA", "year") # get the data

# analyze trends versus the base temperature chart
cor(usa.historical$data, usa.historical$year) # corelation coefficient

# plot the chart using base R graphics
plot(usa.historical$year, usa.historical$data,type = 'l',xlab = 'Year', ylab = 'Temperature',main = 'US temperatures 1900-2010')

# compute three regression models 
lmTemp <- lm(usa.historical$data ~ usa.historical$year) # linear model 
qdTemp <- update(lmTemp, . ~ . + I(usa.historical$year^2)) # quadratic model 
cuTemp = update(qdTemp, . ~ . + I(usa.historical$year^3)) # cubic model

# a function to evluate a polynomial given its coeficients to plot the regression models
polynomial = Vectorize(function(x, ps) {
  n = length(ps)
  sum(ps * x^(1:n-1))
}, "x") 

# plot the temperature data and the regression models 
plot(usa.historical$year, usa.historical$data,type = 'l',xlab = 'Year', ylab = 'Temperature',main = 'US temperatures 1900-2010')
curve(polynomial(x, coef(lmTemp)), add = TRUE, col = 'red') # add the linear model 
curve(polynomial(x, coef(qdTemp)), add = TRUE, col = 'black',lty=2)  # add the quadratic model 
curve(polynomial(x, coef(cuTemp)), add = TRUE, col = 'blue')  # add the cubic model
legend(1900, 8.1, legend = c("linear", "quadratic", "cubic"), lty = c(1,2,1), col = c('red','black','blue')) 

##################################################################################################################

# repeat the above analysis for historical precipitation data 
# in this example we'll download historical precipitation data  
gbr.historical <- get_historical_precip("GBR", "year")

# analyze trends versus the base temperature chart
cor(gbr.historical$data, gbr.historical$year) # corelation coefficient

# plot the chart using base R graphics
plot(gbr.historical$year, gbr.historical$data,type = 'l',xlab = 'Year', ylab = 'Temperature',main = 'UK precipitation 1900-2010')

# compute three regression models 
lmTemp <- lm(gbr.historical$data ~ gbr.historical$year) # linear model 
qdTemp <- update(lmTemp, . ~ . + I(gbr.historical$year^2)) # quadratic model 
cuTemp = update(qdTemp, . ~ . + I(gbr.historical$year^3)) # cubic model

# a function to evluate a polynomial given its coeficients to plot the regression models
polynomial = Vectorize(function(x, ps) {
  n = length(ps)
  sum(ps * x^(1:n-1))
}, "x") 

# plot the temperature data and the regression models 
plot(gbr.historical$year, gbr.historical$data,type = 'l',xlab = 'Year', ylab = 'Temperature',main = 'UK precipitation 1900-2010')
curve(polynomial(x, coef(lmTemp)), add = TRUE, col = 'red') # add the linear model 
curve(polynomial(x, coef(qdTemp)), add = TRUE, col = 'black', lty=2)  # add the quadratic model 
curve(polynomial(x, coef(cuTemp)), add = TRUE, col = 'blue')  # add the cubic model
legend(1900, 120, legend = c("linear", "quadratic", "cubic"), lty = c(1,2,1), col = c('red','black','blue')) 

# repeat the trend analysis for the US
usa.historical <- get_historical_precip("USA", "year") # get the data

# analyze trends versus the base temperature chart
cor(usa.historical$data, usa.historical$year) # corelation coefficient

# plot the chart using base R graphics
plot(usa.historical$year, usa.historical$data,type = 'l',xlab = 'Year', ylab = 'Temperature',main = 'US precipitation 1900-2010')

# compute three regression models 
lmTemp <- lm(usa.historical$data ~ usa.historical$year) # linear model 
qdTemp <- update(lmTemp, . ~ . + I(usa.historical$year^2)) # quadratic model 
cuTemp = update(qdTemp, . ~ . + I(usa.historical$year^3)) # cubic model

# a function to evluate a polynomial given its coeficients to plot the regression models
polynomial = Vectorize(function(x, ps) {
  n = length(ps)
  sum(ps * x^(1:n-1))
}, "x") 

# plot the temperature data and the regression models 
plot(usa.historical$year, usa.historical$data,type = 'l',xlab = 'Year', ylab = 'Temperature',main = 'US precipitation 1900-2010')
curve(polynomial(x, coef(lmTemp)), add = TRUE, col = 'red') # add the linear model 
curve(polynomial(x, coef(qdTemp)), add = TRUE, col = 'black',lty=2)  # add the quadratic model 
curve(polynomial(x, coef(cuTemp)), add = TRUE, col = 'blue')  # add the cubic model
legend(1900, 61, legend = c("linear", "quadratic", "cubic"), lty = c(1,2,1), col = c('red','black','blue')) 

